#include <iostream>
#include <map>
#include <vector>
#include <algorithm>

using namespace std;

typedef long long ll;

class Fenwick {
  map<ll, int> tree;
  ll length;
  
  int treeget (ll idx) {
    if (tree.count(idx) == 0) {
      return 0;
    } else {
      return tree[idx];
    }
  }

  void treeadd (ll idx, int val) {
    if (tree.count(idx) == 0) {
      tree[idx] = 0;
    }
    tree[idx] += val;
  }
  
public:
  Fenwick (ll _length) {
    length = _length;
    tree = map<ll, int> ();
  }

  int get (ll idx) {
    int ans = 0;
    for (ll i = idx; i != 0; i -= i & -i) {
      ans += treeget(i);
    }
    return ans;
  }

  int range (ll l, ll r) {
    return get(r) - get(l - 1);
  }

  void add (ll idx, int val) {
    for (ll i = idx; i < length; i += i & -i) {
      treeadd(i, val);
    }
  }
};

const int MAX_K = 45;
const int HALF = 15;
const ll MAX_N = 1e18 + 5;

ll parties [MAX_K];

int main () {  
  freopen("koalsis.txt", "r", stdin);
  freopen("koalval.txt", "w", stdout);
  
  ll seatc;
  int partyc;
  cin >> seatc >> partyc;

  for (int i = 0; i < partyc; i++) {
    cin >> parties[i];
  }

  sort(parties, parties + partyc, greater<ll> ());

  Fenwick fenwick (MAX_N);
  
  ll ans = 0;
  for (int i = 1; i < 1 << min(HALF, partyc); i++) {
    ll smallest_size = MAX_N;
    ll sum_size = 0;
    for (int j = 0; j < min(HALF, partyc); j++) {
      if (i & 1 << j) {
        sum_size += parties[j];
        smallest_size = min(smallest_size, parties[j]);
      }
    }

    if ((sum_size - smallest_size < seatc / 2 + 1) && (sum_size >= seatc / 2 + 1)) {
      ans++;
    }
    fenwick.add(sum_size, 1);
  }
  
  if (HALF < partyc) {
    for (int i = 1; i < 1 << (partyc - HALF); i++) {
      ll smallest_size = MAX_N;
      ll sum_size = 0;
      for (int j = 0; j < (partyc - HALF); j++) {
        if (i & 1 << j) {
          sum_size += parties[j + HALF];
          smallest_size = min(smallest_size, parties[j + HALF]);
        }
      }

      if ((sum_size - smallest_size < seatc / 2 + 1) && (sum_size >= seatc / 2 + 1)) {
        ans++;
      }

      ans += fenwick.range(seatc / 2 + 1 - sum_size, seatc / 2 - sum_size + smallest_size);
    }
  }

  cout << ans << endl;
}
