#include <iostream>
#include <vector>
#include <set>
#include <cmath>
#include <fstream>

using namespace std;

template<typename T>
ostream& operator<< (ostream &out, const vector<T> &v) {
  for (int i = 0; i < (int) v.size(); i++) {
    out << v[i];
    if (i != (int) v.size() - 1) {
      out << ' ';
    }
  }
  return out;
}

typedef long long ll;

int bitl (ll val) {
  return 64 - __builtin_clzll(val); // "tähvend, ära ropenda!"
}

struct ext_ll { // either long long or infinity
  ll val;
  bool inf;

  ext_ll () {
    val = 0;
    inf = 0;
  }
  
  ext_ll (ll _val) {
    if (bitl(_val) > 60) {
      val = 0;
      inf = 1;
    } else {
      val = _val;
      inf = 0;
    }
  }
};

const ext_ll INF (1LL << 60);

ext_ll operator* (ext_ll p, ext_ll q) {
  if (p.inf || q.inf) {
    return INF;
  }
  
  if (bitl(p.val) + bitl(q.val) > 60) {
    return INF;
  }

  return ext_ll(p.val * q.val);
}

ext_ll operator+ (ext_ll p, ext_ll q) {
  if (p.inf || q.inf) {
    return INF;
  }

  return ext_ll(p.val + q.val);
}

bool operator< (ext_ll p, ext_ll q) {
  if (p.inf) {
    return false;
  }

  if (q.inf) {
    return true;
  }

  return p.val < q.val;
}

ostream& operator<< (ostream &out, ext_ll p) {
  if (p.inf) {
    out << "oo";
  } else {
    out << p.val;
  }
  return out;
}

const int MAX_N = 1e5 + 5;
const int MOD = 1e9 + 7;

ext_ll fact [MAX_N];
ll fact_mod [MAX_N];

ext_ll ways (int x) {
  return fact[x / 2] * fact[(x + 1) / 2];
}

ll ways_mod (int x) {
  return (fact_mod[x / 2] * fact_mod[(x + 1) / 2]) % MOD;
}

ext_ll tot_ways (int x) {
  if (x <= 2) {
    return x;
  } else if (x % 2 == 0) {
    return 2 * ways(x - 2);
  } else {
    return 4 * ways(x - 2);
  }
}

ll tot_ways_mod (int x) {
  if (x <= 2) {
    return x;
  } else if (x % 2 == 0) {
    return (2 * ways_mod(x - 2)) % MOD;
  } else {
    return (4 * ways_mod(x - 2)) % MOD;
  }
}

ll adj_sum (vector<int> v) {
  ll ans = 0;
  for (int i = 0; i < (int) v.size() - 1; i++) {
    ans += abs(v[i + 1] - v[i]);
  }
  return ans;
}

vector<int> solve (int N, ll idx) {
  if (N == 1) {
    return vector<int> (1, 1);
  }
  
  vector<int> ans;
  int last = -1;
  ext_ll pref (0);
  
  set<int> choices [2];
  bool special = false;
  int mode = 0;
  if (N % 2 == 0) {
    if (idx < ways(N - 2)) {
      ans.push_back(N / 2);
      last = N / 2 + 1;
      mode = 0;
    } else {
      ans.push_back(N / 2 + 1);
      last = N / 2;
      pref = pref + ways(N - 2);
      mode = 1;
    }

    for (int i = 1; i < min(ans[0], last); i++) {
      choices[0].insert(i);
    }

    for (int i = max(ans[0], last) + 1; i <= N; i++) {
      choices[1].insert(i);
    }
  } else {
    if (idx < ways(N - 2)) {
      ans.push_back(N / 2);
      last = N / 2 + 1;
      mode = 0;
    } else if (idx < 3 * ways(N - 2)) {
      ans.push_back(N / 2 + 1);
      special = true;
      pref = pref + ways(N - 2);
    } else {
      ans.push_back(N / 2 + 2);
      last = N / 2 + 1;
      pref = pref + 3 * ways(N - 2);
      mode = 1;
    }

    if (!special) {
      for (int i = 1; i < min(ans[0], last); i++) {
        choices[0].insert(i);
      }

      for (int i = max(ans[0], last) + 1; i <= N; i++) {
        choices[1].insert(i);
      }
    }
  }

  for (int i = 1; i <= N - 2; i++) {
    if (special) {
      for (int j = 1; j <= N; j++) {
        if (j != ans[0]) {
          if (pref + ways(N - 2 - i) < idx + 1) {
            pref = pref + ways(N - 2 - i);
          } else {
            ans.push_back(j);
            break;
          }
        }
      }

      if (ans[1] > ans[0]) {
        mode = 1;
        last = ans[0] - 1;
      } else {
        mode = 0;
        last = ans[0] + 1;
      }

      for (int i = 1; i < min(ans[0], last); i++) {
        if (i != ans[1]) {
          choices[0].insert(i);
        }
      }

      for (int i = max(ans[0], last) + 1; i <= N; i++) {
        if (i != ans[1]) {
          choices[1].insert(i);
        }
      }
      
      special = false;
    } else {
      mode = !mode;

      for (int add : choices[mode]) {
        // võiks arvata, et siin on kaks tsüklit ehk teineteise sees ja keerukus O(N^2)
        // tegelikult mitte, kuna meie idx mahub 60 biti sisse.
        // samas ways() kasvab väga suureks väga kiiresti.
        // siin tsüklis ei tehta üle ühe iteratsiooni
        // välja arvatud viimaste ~40 elemendi korral.
        if (pref + ways(N - 2 - i) < idx + 1) {
          pref = pref + ways(N - 2 - i);
        } else {
          ans.push_back(add);
          choices[mode].erase(add);
          break;
        }
      }
    }
  }

  ans.push_back(last);
  return ans;
}

int main () {
  fact[0] = ext_ll(1);
  fact_mod[0] = 1;
  for (int i = 1; i < MAX_N; i++) {
    fact[i] = fact[i - 1] * ext_ll(i);
    fact_mod[i] = (fact_mod[i - 1] * i) % MOD;
  }

  ifstream fin ("svejksis.txt");
  ofstream fout ("svejkval.txt");
  
  int length;
  ll target;
  fin >> length >> target;

  fout << adj_sum(solve(length, 0)) << " " << tot_ways_mod(length) << endl;
  fout << solve(length, 0) << endl;
  fout << solve(length, target - 1) << endl;

  fin.close();
  fout.close();
}
