﻿// O(M*N) lahendus, S on vaba
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;

namespace Tort
{
    static class Program
    {
        static void Main()
        {
            LahendaFail("tortsis.txt", "tortval.txt");
        }

        private static void LahendaFail(string input, string output)
        {
            StreamReader reader = new StreamReader(input);
            string line = reader.ReadLine();
            List<int> parts = line.Split().Select(Int32.Parse).ToList();
            int M = parts[0];
            int N = parts[1];
            int S = parts[2];
            int P = parts[3];
            int Q = parts[4];

            var kokku = new Lahendaja(M, N, S, P, Q).Lahenda();

            StreamWriter writer = new StreamWriter(output);
            writer.WriteLine(kokku);
            writer.Close();
        }

        private class Lahendaja
        {
            private int _m, _n, _s, _p, _q, _s2;
            private readonly Rational _suheX;
            private readonly Rational _suheY;
            private readonly Rational _reduce;
            private readonly Rational _perioodX;
            private readonly Rational _perioodY;
            private readonly Rational _rs2;
            public Lahendaja(int m, int n, int s, int p, int q)
            {
                _m = m;
                _n = n;
                _s = s;
                _p = p;
                _q = q;

                Rational suhe = new Rational(_p, _q);
                _p = suhe.Num;
                _q = suhe.Denom;

                _suheX = new Rational(_p, _q);
                _suheY = new Rational(_q, _p);

                _s2 = _p * _p + _q * _q; // "suure ruudu" pindala
                _rs2 = new Rational(_s2);
                _reduce = (new Rational(_s) / _rs2).ISqrt(); // Because of Quantum

                _perioodX = new Rational(_s2, _q) * _reduce;
                _perioodY = new Rational(_s2, _p) * _reduce;
            }

            public int Lahenda()
            {
                int kokku = _m * _n;
                Rational rm = new Rational(_m);
                kokku += LeiaRuudud(_n, _m, Rational.Zero, _perioodX, _suheX);  // tousvad diagonaalid, alt küljest 
                kokku += LeiaRuudud(_m, _n, _perioodY, _perioodY, _suheY);  // tousvad diagonaalid, vasakult küljest 

                Rational esimene = (new Rational(_p) + new Rational(_q) * _suheY) * _reduce;
                Rational viimane = (rm - esimene) % _perioodY;
                kokku += LeiaRuudud(_n, _m, viimane, _perioodY, _suheY);  // langevad diagonaalid, alt küljest 

                Rational yleyhe = rm - viimane + _perioodY;
                Rational kyljel = (yleyhe - rm) * _suheX;
                kokku += LeiaRuudud(_m, _n, kyljel, _perioodX, _suheX);  // langevad diagonaalid, paremalt küljest 

                kokku += LeiaRistid();
                return kokku;
            }

            private int LeiaRuudud(int ridu, int veerge, Rational algusX, Rational periood, Rational suhe)
            {
                int c = 0;
                Rational rv = new Rational(veerge);
                for (; algusX < veerge; algusX += periood)
                {
                    Rational loppX;
                    // kas ulatub teise serva?
                    if ((rv - algusX) / suhe >= ridu)
                    {
                        loppX = algusX + ridu * suhe;
                    }
                    else
                    {
                        loppX = new Rational(veerge);
                    }

                    Rational pikkus = loppX - algusX;
                    Rational korgus = pikkus / suhe;

                    c += korgus.Ceil() - 1;  // vert ruudud
                    c += loppX.Ceil() - algusX.Floor(); // hor ruudud

                    Rational y = Rational.Zero;
                    Rational x = algusX;
                    while(x < loppX)
                    {
                        Rational delta = Rational.One - x % Rational.One;
                        x += delta;
                        if (x >= loppX) break;
                        y += delta / suhe;
                        if (y.IsInt)
                        {
                            c--;
                        }
                    }
                }

                return c;
            }

            private int LeiaRistid()
            {
                int c = 0;
                c += LoeRiste(_m, _n, _perioodX, _q * _reduce, _p * _reduce, _suheX, true);  // vasakult paremale 
                c += LoeRiste(_n, _m, _perioodY, _p * _reduce, _q * _reduce, _suheY, false);  // alt yles

                return c;
            }

            private static int LoeRiste(int veerge, int ridu, Rational periood, Rational reakasv, Rational veerukasv, Rational suhe, bool countFirst)
            {
                int c = 0;
                Rational ristAlgY = Rational.Zero;
                for (Rational kaldX = Rational.Zero; kaldX < veerge; kaldX += periood)  // tousjooned vasakult paremale
                {
                    while (ristAlgY < 0)
                    {
                        ristAlgY += reakasv;
                    }

                    Rational ristAlgX = kaldX + ristAlgY * suhe;
                    for (Rational ristY = ristAlgY, ristX = ristAlgX; ristY < ridu && ristX < veerge; ristY += reakasv, ristX += veerukasv)  // langjooned alt yles
                    {
                        if (!(ristX.IsInt && ristY.IsInt) && (kaldX > Rational.Zero || countFirst))
                        {
                            c++;
                        }
                    }

                    ristAlgY -= veerukasv; // vajumisnaitaja
                }

                return c;
            }
        }

        public class Rational
        {
            private int _numerator = 0;
            private int _denominator = 1;

            public Rational(int intvalue)
            {
                Set(intvalue, 1);
            }

            public Rational(int numerator, int denominator)
            {
                Set(numerator, denominator);
                Reduce();
            }

            public static Rational One => new Rational(1);
            public static Rational Zero => new Rational(0);

            public int Num => _numerator;
            public int Denom => _denominator;

            public bool IsInt => _denominator == 1;

            private void Set(int numerator, int denominator)
            {
                if (denominator == 0)
                {
                    throw new ArithmeticException("Denominator must not be 0");
                }

                _numerator = numerator;
                _denominator = denominator;
            }

            private static Tuple<int, int> CommonBase(Rational r1, Rational r2)
            {
                int lcm = Lcm(r1._denominator, r2._denominator);
                int num1 = lcm / r1._denominator * r1._numerator;
                int num2 = lcm / r2._denominator * r2._numerator;

                return new Tuple<int, int>(num1, num2);
            }

            private static int Lcm(int v1, int v2)
            {
                return v1 * v2 / Gcd(v1, v2);
            }

            private static int Gcd(int a, int b)
            {
                if (a == 0)
                    return b;
                return Gcd(b % a, a);
            }

            private void Reduce()
            {
                int divisor = Math.Sign(_denominator) * Gcd(Math.Abs(_numerator), Math.Abs(_denominator));
                if (divisor == 0)
                {
                    _numerator = 0;
                    _denominator = 1;
                }
                else
                {
                    _numerator /= divisor;
                    _denominator /= divisor;
                }
            }

            private static int ISqrt(int n)
            {
                int current = n;
                int next = 1;
                while (current != next)  // newtoni meetod
                {
                    current = next;
                    next = (current + n / current) / 2;
                }

                return current;
            }

            public Rational ISqrt()
            {
                return new Rational(ISqrt(Num), ISqrt(Denom));
            }

            public int Ceil()
            {
                return Num / Denom + Math.Sign(Num % Denom);
            }

            public int Floor()
            {
                return Num / Denom;
            }

            public static bool operator ==(Rational r1, Rational r2)
            {
                if (ReferenceEquals(r1, null) && ReferenceEquals(r2, null)) return true;
                if (ReferenceEquals(r1, null) || ReferenceEquals(r2, null)) return false;

                r1.Reduce();
                r2.Reduce();
                return (r1._numerator == r2._numerator && r1._denominator == r2._denominator);
            }

            public static bool operator ==(Rational r1, int n)
            {
                r1.Reduce();
                return (r1.IsInt && r1.Num == n);
            }

            public static bool operator !=(Rational r1, int n)
            {
                return !(r1 == n);
            }

            public static bool operator !=(Rational r1, Rational r2)
            {
                return !(r1 == r2);
            }

            public static bool operator <(Rational r1, Rational r2)
            {
                var cb = CommonBase(r1, r2);
                return cb.Item1 < cb.Item2;
            }

            public static bool operator <(Rational r1, int n)
            {
                return r1._numerator < r1._denominator * n;
            }

            public static bool operator >(Rational r1, int n)
            {
                return r1._numerator > r1._denominator * n;
            }

            public static bool operator <=(Rational r1, int n)
            {
                return r1._numerator <= r1._denominator * n;
            }

            public static bool operator >=(Rational r1, int n)
            {
                return r1._numerator >= r1._denominator * n;
            }

            public static bool operator <=(Rational r1, Rational r2)
            {
                var cb = CommonBase(r1, r2);
                return cb.Item1 <= cb.Item2;
            }

            public static bool operator >=(Rational r1, Rational r2)
            {
                return r2 <= r1;
            }

            public static bool operator >(Rational r1, Rational r2)
            {
                return r2 < r1;
            }

            public static explicit operator double(Rational r)
            {
                return (double)r._numerator / (double)r._denominator;
            }

            public static Rational operator -(Rational r)
            {
                return new Rational(-r._numerator, r._denominator);
            }

            public static Rational operator +(Rational r1, Rational r2)
            {
                var cb = CommonBase(r1, r2);
                return new Rational(cb.Item1 + cb.Item2, Lcm(r1._denominator, r2._denominator));
            }

            public static Rational operator -(Rational r1, Rational r2)
            {
                return r1 + -r2;
            }

            public static Rational operator *(Rational r1, Rational r2)
            {
                return new Rational(r1._numerator * r2._numerator, r1._denominator * r2._denominator);
            }

            public static Rational operator *(int n, Rational r2)
            {
                return new Rational(n * r2._numerator, r2._denominator);
            }

            public static Rational operator /(Rational r1, Rational r2)
            {
                if (r2._numerator == 0)
                {
                    throw new DivideByZeroException();
                }

                int num = r1._numerator * r2._denominator;
                int den = r1._denominator * r2._numerator;
                return new Rational(num, den);
            }

            public static Rational operator %(Rational r1, Rational r2)
            {
                if (r2._numerator == 0)
                {
                    throw new DivideByZeroException();
                }

                Rational res = r1 - new Rational((r1 / r2).Floor()) * r2;
                if(res < 0)
                {
                    res += r2;
                }

                return res;
            }

            public override string ToString()
            {
                return _denominator == 1 ? _numerator.ToString() : $"({_numerator}/{_denominator})";
            }

            public Rational Recip()
            {
                return new Rational(Denom, Num);
            }
        }
            
    }
}
