﻿// O(P^2+Q^2) lahendus
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;

namespace Tort
{
    static class Program
    {
        static void Main()
        {
            LahendaFail("tortsis.txt", "tortval.txt");
        }

        private static void LahendaFail(string input, string output)
        {
            StreamReader reader = new StreamReader(input);
            string line = reader.ReadLine();
            List<int> parts = line.Split().Select(int.Parse).ToList();
            int M = parts[0];
            int N = parts[1];
            int S = parts[2];
            int P = parts[3];
            int Q = parts[4];

            var kokku = new Lahendaja(M, N, S, P, Q).Lahenda();

            StreamWriter writer = new StreamWriter(output);
            writer.WriteLine(kokku);
            writer.Close();
        }

        private class Lahendaja
        {
            private long _m, _n, _s, _p, _q, _s2;
            private readonly Rational _suheX;
            private readonly Rational _suheY;
            private readonly Rational _reduce;
            private readonly Rational _perioodX;
            private readonly Rational _perioodY;
            private readonly Rational _rs2;
            public Lahendaja(long m, long n, long s, long p, long q)
            {
                _m = m;
                _n = n;
                _s = s;
                _p = p;
                _q = q;

                Rational suhe = new Rational(_p, _q);
                suhe.Reduce();
                _p = suhe.Num;
                _q = suhe.Denom;

                _suheX = new Rational(_p, _q);
                _suheY = new Rational(_q, _p);

                _s2 = _p * _p + _q * _q; // "suure ruudu" pindala
                _rs2 = new Rational(_s2);
                _reduce = (new Rational(_s) / _rs2).ISqrt(); // Because of Quantum

                _perioodX = new Rational(_s2, _q) * _reduce;
                _perioodY = new Rational(_s2, _p) * _reduce;
            }

            public long Lahenda()
            {
                long kylg = _s2 * _reduce.Num;
                long kokku = 0;

                long laiuti = _m / kylg;
                long pikuti = _n / kylg;
                kokku += laiuti * pikuti * LahendaOsa(kylg, kylg);
                kokku += laiuti * LahendaOsa(kylg, _n % kylg);
                kokku += pikuti * LahendaOsa(_m % kylg, kylg);
                kokku += LahendaOsa(_m % kylg, _n % kylg);
                return kokku;
            }

            private long LahendaOsa(long m, long n)
            {
                long kokku = m * n;
                if (kokku == 0) return 0;

                Rational rm = new Rational(m);
                kokku += LeiaRuudud(n, m, Rational.Zero, _perioodX, _suheX);  // tousvad diagonaalid, alt küljest 
                kokku += LeiaRuudud(m, n, _perioodY, _perioodY, _suheY);  // tousvad diagonaalid, vasakult küljest 

                Rational esimene = (new Rational(_p) + new Rational(_q) * _suheY) * _reduce;
                Rational viimane = (rm - esimene) % _perioodY;
                kokku += LeiaRuudud(n, m, viimane, _perioodY, _suheY);  // langevad diagonaalid, alt küljest 

                Rational yleyhe = rm - viimane + _perioodY;
                Rational kyljel = (yleyhe - rm) * _suheX;
                kokku += LeiaRuudud(m, n, kyljel, _perioodX, _suheX);  // langevad diagonaalid, paremalt küljest 

                kokku += LeiaRistid(m, n);
                return kokku;
            }

            private long LeiaRuudud(long ridu, long veerge, Rational algusX, Rational periood, Rational suhe)
            {
                long c = 0;
                Rational rv = new Rational(veerge);
                for (; algusX < veerge; algusX += periood)
                {
                    Rational loppX;
                    // kas ulatub teise serva?
                    if ((rv - algusX) / suhe >= ridu)
                    {
                        loppX = algusX + ridu * suhe;
                    }
                    else
                    {
                        loppX = new Rational(veerge);
                    }

                    Rational pikkus = loppX - algusX;
                    Rational korgus = pikkus / suhe;

                    c += korgus.Ceil() - 1;  // vert ruudud
                    c += loppX.Ceil() - algusX.Floor(); // hor ruudud

                    Rational y = Rational.Zero;
                    Rational x = algusX;
                    int kordaja = 1;
                    bool algus = true;
                    bool lopp = false;
                    int loend = 0;
                    while(x < loppX)
                    {
                        Rational delta = x.IsInt ? Rational.One : Rational.One - x % Rational.One;
                        if (kordaja > 1 && x + kordaja * delta > loppX)
                        {
                            kordaja = 1;
                            lopp = true;
                        }

                        x += kordaja * delta;
                        if (x >= loppX) break;

                        y += kordaja * delta / suhe;
                        if (!algus && kordaja == 1)
                        {
                            loend++;
                        }

                        if (y.IsInt)
                        {
                            if (algus)
                            {
                                algus = false;
                            }
                            else
                            {
                                if (loend > 0 && kordaja == 1 && !lopp)
                                {
                                    kordaja = loend;
                                    if (kordaja == 1) loend = 0;
                                }
                            }
                            c--;
                        }
                    }
                }

                return c;
            }

            private long LeiaRistid(long m, long n)
            {
                long c = 0;
                c += LoeRiste(m, n, _perioodX, _q * _reduce, _p * _reduce, _suheX, true);  // vasakult paremale 
                c += LoeRiste(n, m, _perioodY, _p * _reduce, _q * _reduce, _suheY, false);  // alt yles

                return c;
            }

            private static long LoeRiste(long veerge, long ridu, Rational periood, Rational reakasv, Rational veerukasv, Rational suhe, bool countFirst)
            {
                long c = 0;
                Rational ristAlgY = Rational.Zero;
                for (Rational kaldX = Rational.Zero; kaldX < veerge; kaldX += periood)  // tousjooned vasakult paremale
                {
                    if (kaldX == Rational.Zero && !countFirst)
                    {
                        ristAlgY -= veerukasv; // vajumisnaitaja
                        continue;
                    }

                    while (ristAlgY < 0)
                    {
                        ristAlgY += reakasv;
                    }

                    Rational ristAlgX = kaldX + ristAlgY * suhe;
                    int kordaja = 1;
                    bool algus = true;
                    bool lopp = false;
                    int loend = 0;
                    Rational ristY = ristAlgY, ristX = ristAlgX;
                    while(ristY < ridu && ristX < veerge)  // langjooned alt yles
                    {
                        c += kordaja;
                        if (!algus && kordaja == 1)
                        {
                            loend++;
                        }

                        if (ristX.IsInt && ristY.IsInt)
                        {
                            if (algus)
                            {
                                algus = false;
                            }
                            else
                            {
                                if (loend > 0 && kordaja == 1 && !lopp)
                                {
                                    kordaja = loend;
                                    if (kordaja == 1) // ainult solmed
                                    {
                                        c--;
                                        break;
                                    }
                                }
                            }
                            c--;
                        }

                        if (kordaja > 1 && (ristY + kordaja * reakasv >= ridu || ristX + kordaja * veerukasv >= veerge))
                        {
                            kordaja = 1;
                            lopp = true;
                        }
                        ristY += kordaja * reakasv;
                        ristX += kordaja * veerukasv;
                    }

                    ristAlgY -= veerukasv; // vajumisnaitaja
                }

                return c;
            }
        }

        public class Rational
        {
            private long _numerator = 0;
            private long _denominator = 1;
            private bool _reduced = false;

            public Rational(long longvalue)
            {
                Set(longvalue, 1);
            }

            public Rational(long numerator, long denominator)
            {
                Set(numerator, denominator);
            }

            public static Rational One => new Rational(1);
            public static Rational Zero => new Rational(0);

            public long Num => _numerator;
            public long Denom => _denominator;

            public bool IsInt => _denominator == 1;

            private void Set(long numerator, long denominator)
            {
                if (denominator == 0)
                {
                    throw new ArithmeticException("Denominator must not be 0");
                }

                _numerator = numerator;
                _denominator = denominator;

                if (_denominator == 1) _reduced = true;
            }

            private static Tuple<long, long> CommonBase(Rational r1, Rational r2)
            {
                long lcm = Lcm(r1._denominator, r2._denominator);
                long num1 = lcm / r1._denominator * r1._numerator;
                long num2 = lcm / r2._denominator * r2._numerator;

                return new Tuple<long, long>(num1, num2);
            }

            private static long Lcm(long v1, long v2)
            {
                if (v1 == v2) return v1;
                return v1 * v2 / Gcd(v1, v2);
            }

            private static long Gcd(long a, long b)
            {
                if (a == 0)
                    return b;
                return Gcd(b % a, a);
            }

            public void Reduce()
            {
                if (_reduced) return;
                long divisor = Math.Sign(_denominator) * Gcd(Math.Abs(_numerator), Math.Abs(_denominator));
                if (divisor == 0)
                {
                    _numerator = 0;
                    _denominator = 1;
                }
                else
                {
                    _numerator /= divisor;
                    _denominator /= divisor;
                }

                _reduced = true;
            }

            private static long ISqrt(long n)
            {
                long current = n;
                long next = 1;
                while (current != next)  // newtoni meetod
                {
                    current = next;
                    next = (current + n / current) / 2;
                }

                return current;
            }

            public Rational ISqrt()
            {
                return new Rational(ISqrt(Num), ISqrt(Denom));
            }

            public long Ceil()
            {
                return Num / Denom + Math.Sign(Num % Denom);
            }

            public long Floor()
            {
                return Num / Denom;
            }

            public static bool operator ==(Rational r1, Rational r2)
            {
                if (ReferenceEquals(r1, null) && ReferenceEquals(r2, null)) return true;
                if (ReferenceEquals(r1, null) || ReferenceEquals(r2, null)) return false;

                r1.Reduce();
                r2.Reduce();
                return (r1._numerator == r2._numerator && r1._denominator == r2._denominator);
            }

            public static bool operator ==(Rational r1, long n)
            {
                r1.Reduce();
                return (r1.IsInt && r1.Num == n);
            }

            public static bool operator !=(Rational r1, long n)
            {
                return !(r1 == n);
            }

            public static bool operator !=(Rational r1, Rational r2)
            {
                return !(r1 == r2);
            }

            public static bool operator <(Rational r1, Rational r2)
            {
                var cb = CommonBase(r1, r2);
                return cb.Item1 < cb.Item2;
            }

            public static bool operator <(Rational r1, long n)
            {
                return r1._numerator < r1._denominator * n;
            }

            public static bool operator >(Rational r1, long n)
            {
                return r1._numerator > r1._denominator * n;
            }

            public static bool operator <=(Rational r1, long n)
            {
                return r1._numerator <= r1._denominator * n;
            }

            public static bool operator >=(Rational r1, long n)
            {
                return r1._numerator >= r1._denominator * n;
            }

            public static bool operator <=(Rational r1, Rational r2)
            {
                var cb = CommonBase(r1, r2);
                return cb.Item1 <= cb.Item2;
            }

            public static bool operator >=(Rational r1, Rational r2)
            {
                return r2 <= r1;
            }

            public static bool operator >(Rational r1, Rational r2)
            {
                return r2 < r1;
            }

            public static explicit operator double(Rational r)
            {
                return (double)r._numerator / (double)r._denominator;
            }

            public static Rational operator -(Rational r)
            {
                return new Rational(-r._numerator, r._denominator);
            }

            public static Rational operator +(Rational r1, Rational r2)
            {
                Rational res;
                if (r1.Denom == r2.Denom)
                {
                    res = new Rational(r1.Num + r2.Num, r1.Denom);
                }
                else
                {
                    var cb = CommonBase(r1, r2);
                    res = new Rational(cb.Item1 + cb.Item2, Lcm(r1._denominator, r2._denominator));
                }
                res.Reduce();
                return res;
            }

            public static Rational operator -(Rational r1, Rational r2)
            {
                return r1 + -r2;
            }

            public static Rational operator *(Rational r1, Rational r2)
            {
                var res = new Rational(r1._numerator * r2._numerator, r1._denominator * r2._denominator);
                res.Reduce();
                return res;
            }

            public static Rational operator *(long n, Rational r2)
            {
                var res = new Rational(n * r2._numerator, r2._denominator);
                res.Reduce();
                return res;
            }

            public static Rational operator /(Rational r1, Rational r2)
            {
                if (r2._numerator == 0)
                {
                    throw new DivideByZeroException();
                }

                long num = r1._numerator * r2._denominator;
                long den = r1._denominator * r2._numerator;
                var res = new Rational(num, den);
                res.Reduce();
                return res;
            }

            public static Rational operator %(Rational r1, Rational r2)
            {
                if (r2._numerator == 0)
                {
                    throw new DivideByZeroException();
                }

                Rational res = r1 - new Rational((r1 / r2).Floor()) * r2;
                if(res < 0)
                {
                    res += r2;
                }

                return res;
            }

            public override string ToString()
            {
                return _denominator == 1 ? _numerator.ToString() : $"({_numerator}/{_denominator})";
            }

            public Rational Recip()
            {
                return new Rational(Denom, Num);
            }
        }
            
    }
}
