#include <iostream>
#include <fstream>

using namespace std;

typedef long long ll;

template<typename T, typename U>
ostream& operator<< (ostream &out, pair<T, U> pr) {
  out << pr.first << " " << pr.second;
  return out;
}

ll gcd (ll p, ll q) {
  if (q == 0) return p;
  return gcd(q, p % q);
}

pair<ll, ll> bezout (ll p, ll q) {
  pair<ll, ll> lcoefs = make_pair(1, 0);
  pair<ll, ll> rcoefs = make_pair(0, 1);
  while (true) {
    ll rem = p % q;
    if (rem == 0) return rcoefs;
    ll quo = p / q;
    pair<ll, ll> ncoefs = make_pair(lcoefs.first - quo * rcoefs.first,
                                    lcoefs.second - quo * rcoefs.second);
    lcoefs = rcoefs;
    rcoefs = ncoefs;
    p = q;
    q = rem;
  }
}

ll lcm (ll p, ll q) {
  return (p / gcd(p, q)) * q;
}

struct frac {
  ll p, q;

  frac () : p(0), q(1) {}

  frac (ll _p) : p(_p), q(1) {}

  frac (ll _p, ll _q) {
    ll gc = gcd(_p, _q);
    p = _p / gc;
    q = _q / gc;

    if (q < 0) {
      q *= -1;
      p *= -1;
    }
  }
};

frac operator+ (frac x, frac y) {
  return frac(x.p * y.q + x.q * y.p, x.q * y.q);
}

frac operator- (frac x) {
  return frac(-x.p, x.q);
}

frac operator- (frac x, frac y) {
  return x + (-y);
}

frac operator* (frac x, frac y) {
  return frac(x.p * y.p, x.q * y.q);
}

frac operator/ (frac x, frac y) {
  return frac(x.p * y.q, x.q * y.p);
}

bool operator== (frac x, frac y) {
  return x.p * y.q == x.q * y.p;
}

bool operator< (frac x, frac y) {
  return x.p * y.q < x.q * y.p;
}

bool operator<= (frac x, frac y) {
  return x < y || x == y;
}

bool operator> (frac x, frac y) {
  return x.p * y.q > x.q * y.p;
}

bool operator>= (frac x, frac y) {
  return x > y || x == y;
}

bool operator!= (frac x, frac y) {
  return !(x == y);
}

ostream& operator<< (ostream &out, frac x) {
  out << x.p << '/' << x.q;
  return out;
}

ll floor (frac x) {
  return x.p / x.q;
}

ll ceil (frac x) {
  return (x.p + x.q - 1) / x.q;
}

int int_sqrt (int x) {
  for (int i = 0; i * i <= x; i++) {
    if (i * i == x) {
      return i;
    }
  }
  return 0;
}

frac frac_sqrt (frac x) {
  return frac(int_sqrt(x.p), int_sqrt(x.q));
}

frac r;
frac calc_vjump (int P, int Q) {
  return r * frac(P * P + Q * Q, P);
}

frac calc_hjump (int P, int Q) {
  return r * frac(P * P + Q * Q, Q);
}

pair<frac, frac> crt (pair<frac, frac> a, pair<frac, frac> b) { // <period, offset>
  ll lc = lcm(lcm(a.first.q, a.second.q), lcm(b.first.q, b.second.q)); // <= 1e6
  ll m = a.first.p * (lc / a.first.q);
  ll n = b.first.p * (lc / b.first.q);
  ll g = gcd(m, n);
  ll x = a.second.p * (lc / a.second.q);
  ll y = b.second.p * (lc / b.second.q); // <= 4.6e10
  if (x % g != y % g) {
    return make_pair(0, 0);
  }
  pair<ll, ll> uv = bezout(m / g, n / g);
  ll period = lcm(m, n);
  ll offset = (y * uv.first * (m / g) + x * uv.second * (n / g)) % period;
  if (offset < 0) offset += period;
  return make_pair(frac(period, lc), frac(offset, lc));
}

//   |
// --+--
//   |
ll grid_crosses (int M, int N) {
  return (ll) M * (ll) N;
}

//  \ /
//   x
//  / \.
// TODO: with Pick's theorem (or iterating)
ll diag_crosses (int M, int N, int S, int P, int Q) {
  frac vjump = calc_vjump(P, Q);
  frac hjump = calc_hjump(P, Q);

  ll ans = 0;
  frac rev_start = 0;
  for (frac base = 0; base < M; base = base + hjump) {
    while (rev_start < base) {
      rev_start = rev_start + vjump;
    }

    frac crossx = (frac(Q * Q) * base + frac(P * P) * rev_start) / frac(Q * Q + P * P);
    frac crossy = frac(Q, P) * crossx - frac(Q, P) * base;

    ll byx;
    if (crossx < frac(M)) {
      byx = ceil((M - crossx) / (r * P));
    } else {
      byx = 0;
    }

    ll byy;
    if (crossy < frac(N)) {
      byy = ceil((N - crossy) / (r * Q));
    } else {
      byy = 0;
    }

    ans += min(byx, byy);
  }

  rev_start = 0;
  for (frac base = vjump; base < N; base = base + vjump) {
    while (rev_start < base) {
      rev_start = rev_start + hjump;
    }

    frac crossx = (frac(P * P) * base + frac(Q * Q) * rev_start) / frac(Q * Q + P * P);
    frac crossy = frac(P, Q) * crossx - frac(P, Q) * base;

    ll byx;
    if (crossx < frac(N)) {
      byx = ceil((N - crossx) / (r * Q));
    } else {
      byx = 0;
    }

    ll byy;
    if (crossy < frac(M)) {
      byy = ceil((M - crossy) / (r * P));
    } else {
      byy = 0;
    }

    ans += min(byx, byy);    
  }
  return ans - 1;
}

//   |/
// --*--
//  /|
ll grid_threeways (int M, int N, int S, int P, int Q) {
  frac last_start = 0;
  frac hjump = calc_hjump(P, Q);
  frac vjump = calc_vjump(P, Q);
  ll ans = 0;
  for (int i = 0; i < M; i++) {
    while (last_start + hjump <= frac(i)) {
      last_start = last_start + hjump;
    }

    pair<frac, frac> diag = make_pair(vjump, frac(Q, P) * (frac(i) - last_start));
    pair<frac, frac> vert = make_pair(frac(1), 0);
    pair<frac, frac> combined = crt(diag, vert);
    if (combined.first.p != 0 && combined.second <= frac(N)) {
      ans += ceil((frac(N) - combined.second) / combined.first);
    }
  }
  return ans;
}

//  \|
// --*--
//   |\.
ll grid_rthreeways (int M, int N, int S, int P, int Q) {
  frac hjump = calc_hjump(P, Q);
  frac vjump = calc_vjump(P, Q);
  frac last_start = 0;
  ll ans = 0;
  for (int i = 0; i < M; i++) {
    while (frac(i) > last_start) {
      last_start = last_start + vjump;
    }

    pair<frac, frac> rdiag = make_pair(hjump, frac(P, Q) * (last_start - frac(i)));
    pair<frac, frac> vert = make_pair(frac(1), 0);
    pair<frac, frac> combined = crt(rdiag, vert);
    if (combined.first.p != 0 && combined.second <= frac(N)) {
      ans += ceil((frac(N) - combined.second) / combined.first);
    }
  }
  return ans - 1;
}

//  \|/
//   *
//  /|\.
ll diag_threeways (int M, int N, int S, int P, int Q) {
  frac dlast_start = 0;
  frac rlast_start = 0;
  frac hjump = calc_hjump(P, Q);
  frac vjump = calc_vjump(P, Q);
  ll ans = 0;
  for (int i = 0; i < M; i++) {
    while (dlast_start + hjump <= frac(i)) {
      dlast_start = dlast_start + hjump;
    }
    while (frac(i) > rlast_start) {
      rlast_start = rlast_start + vjump;
    }

    pair<frac, frac> diag = make_pair(vjump, frac(Q, P) * (frac(i) - dlast_start));
    pair<frac, frac> rdiag = make_pair(hjump, frac(P, Q) * (rlast_start - frac(i)));
    pair<frac, frac> combined = crt(diag, rdiag);
    if (combined.first.p != 0 && combined.second <= frac(N)) {
      ans += ceil((frac(N) - combined.second) / combined.first);
    }
  }
  return ans - 1;
}

//  \|/
// --*--
//  /|\.
ll fourways (int M, int N, int S, int P, int Q) {
  frac dlast_start = 0;
  frac rlast_start = 0;
  frac hjump = calc_hjump(P, Q);
  frac vjump = calc_vjump(P, Q);
  ll ans = 0;
  for (int i = 0; i < M; i++) {
    while (dlast_start + hjump <= frac(i)) {
      dlast_start = dlast_start + hjump;
    }
    while (frac(i) > rlast_start) {
      rlast_start = rlast_start + vjump;
    }

    pair<frac, frac> diag = make_pair(vjump, frac(Q, P) * (frac(i) - dlast_start));
    pair<frac, frac> rdiag = make_pair(hjump, frac(P, Q) * (rlast_start - frac(i)));
    pair<frac, frac> vert = make_pair(1, 0);
    pair<frac, frac> icombined = crt(diag, rdiag);
    if (icombined.first.p != 0) {
      pair<frac, frac> combined = crt(icombined, vert);
      if (combined.first.p != 0 && combined.second <= frac(N)) {
        ans += ceil((frac(N) - combined.second) / combined.first);
      }
    }
  }
  return ans - 1;
}

//   |/
//   .
//  /|
ll acutes (int M, int N, int S, int P, int Q) {
  frac last_start = 0;
  frac hjump = calc_hjump(P, Q);
  frac vjump = calc_vjump(P, Q);
  ll ans = 0;
  for (int i = 0; i < M; i++) {
    while (last_start + hjump <= frac(i)) {
      last_start = last_start + hjump;
    }

    frac first_cross = frac(Q, P) * (frac(i) - last_start);
    if (first_cross <= frac(N)) {
      ans += ceil((frac(N) - first_cross) / vjump);
    }
  }
  return ans;
}

//  \|
//   .
//   |\.
ll racutes (int M, int N, int S, int P, int Q) {
  frac hjump = calc_hjump(P, Q);
  frac vjump = calc_vjump(P, Q);
  frac last_start = 0;
  ll ans = 0;
  for (int i = 0; i < M; i++) {
    while (frac(i) > last_start) {
      last_start = last_start + vjump;
    }

    frac first_cross = frac(P, Q) * (last_start - frac(i));
    if (first_cross <= frac(N)) {
      ans += ceil((frac(N) - first_cross) / hjump);
    }
  }
  return ans - 1;
}

ll backds (int M, int N, int S, int P, int Q) {
  frac hjump = calc_hjump(P, Q);
  frac vjump = calc_vjump(P, Q);
  frac last_start = 0;
  ll ans = 0;
  int i = M;
  while (frac(i) > last_start) {
    last_start = last_start + vjump;
  }

  frac first_cross = frac(P, Q) * (last_start - frac(i));
  if (first_cross <= frac(N)) {
    ans += ceil((frac(N) - first_cross) / hjump);
  }
  return ans;
}

ll frontds (int M, int N, int S, int P, int Q) {
  frac hjump = calc_hjump(P, Q);
  if (N < hjump) {
    return 0;
  }
  return ceil((frac(N) - hjump) / hjump);
}

ll solve_simple (int M, int N, int S, int P, int Q) {
  if (M == 0 || N == 0) {
    return 0;
  }

  ll fwc = fourways(M, N, S, P, Q);
  
  ll gtw = grid_threeways(M, N, S, P, Q) - fwc;
  ll grw = grid_rthreeways(M, N, S, P, Q) - fwc;
  ll dtw = diag_threeways(M, N, S, P, Q) - fwc;
  ll idtw = diag_threeways(N, M, S, Q, P) - fwc;

  cout << fwc << " " << gtw << " " << grw << " " << dtw << " " << idtw << endl;

  ll acc = acutes(M, N, S, P, Q) - dtw - gtw - fwc;
  ll racc = racutes(M, N, S, P, Q) - dtw - grw - fwc;
  ll iacc = acutes(N, M, S, Q, P) - idtw - gtw - fwc;
  ll iracc = racutes(N, M, S, Q, P) - idtw - grw - fwc;
  ll dcc = diag_crosses(M, N, S, P, Q) - dtw - idtw -fwc;
  ll gcc = grid_crosses(M, N) - gtw - grw - fwc;

  ll pathd = min(backds(M, N, S, P, Q), backds(N, M, S, Q, P));
  ll rpathd = min(frontds(M, N, S, P, Q), frontds(N, M, S, Q, P));

  cout << acc << " " << racc << " " << iacc << " " << iracc << " " << dcc << " " << gcc << " "
       << pathd << " " << rpathd << endl;

  cout << 3 * fwc + 2 * (gtw + grw + dtw + idtw) + (acc + racc + iacc + iracc + dcc + gcc) + pathd - rpathd << endl << endl;
  return 3 * fwc + 2 * (gtw + grw + dtw + idtw) + (acc + racc + iacc + iracc + dcc + gcc) + pathd - rpathd;
}

ll solve (int M, int N, int S, int P, int Q) {
  r = frac_sqrt(frac(S, P * P + Q * Q));
  
  ll mod = (Q * frac(P * P + Q * Q, Q) * r).p;
  cout << mod << endl;
  
  return (M / mod) * (N / mod) * solve_simple(mod, mod, S, P, Q)
    + (M / mod) * solve_simple(mod, N % mod, S, P, Q)
    + (N / mod) * solve_simple(M % mod, mod, S, P, Q)
    + solve_simple(M % mod, N % mod, S, P, Q);
}

int main () {
  ifstream fin ("tortsis.txt");
  int M, N, S, P, Q;
  fin >> M >> N >> S >> P >> Q;
  fin.close();

  ofstream fout ("tortval.txt");
  fout << solve(M, N, S, P, Q) << endl;
  fout.close();
}
